/*
 OpenCL Kernel for matric multiply

 To enable syntax highlighting for *.cl in Code::Blocks do as follows:
  1. Select from main menu: Settings -> Editor -> Syntax Highlighting
  2. At the top right of the Syntax Highlighting dialog press on 'Filemasks'
  3. Add *.cl to the list of C/C++ filemasks
  4. Click OK, and click OK in syntax highlighting dialog
  5. Now the *.cl files should have C/C++ syntax highlighting enabled.

 */

/** This Kernel perform part of a standard matrix multiply on two NxN matrices,
    calculating one of the output elements: Sum of A(k,i) x B(j,k) for k=0..N-1. */
__kernel
void Multiply(
   __global float*       A,
   __global float*       B,
   __global float*       Output,
   const    unsigned int N
){
 const int i = get_global_id(1); // Row    - this was
 const int j = get_global_id(0); // Column -

 int k;
 float result = 0;
 for(k = 0; k < N; k++){
  result += A[N*i + k] * B[N*k + j];
 }
 Output[N*j + i] = result;
}
//------------------------------------------------------------------------------

